/* ------------------------------------------------------------ 
 *
 *  Analytic functions for ice sheet modified Stokes model.
 *
 *
 *  Usage:
 *     call func_init_params(L, alpah) to set parameters,
 *     call set_func_time(t) to set time
 *     call func_u, func_v, func_w func_p to get velocty and pressure
 *     call func_mu get visocity
 *     call func_F get compensation terms for momentum equations
 *     call func_f get compensation terms for upper surface
 *
 *  Note:
 *     Input and Output unit of each function is listed at
 *     the begenning of the function.
 *  
 *
 *
 * ------------------------------------------------------------
 * */
#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#define SQU(x) (x)*(x)
#define MPi 3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679821480865132823066470938446095505822317253594081284811174502841027019385211055596446229489549303819644288109756659334461284756482337867831652712019091456485669234603486104543266482 

#define delta D


double cx;
double cbx;
double cy;
double cby;
double ct;


/* Basic parameters */
static double t;

static double Lx;
static double alpha;
static double n;
static double rho;
static double g;
static double A;
static double spyr;
static double Sx;
static double Sz;
static double D;


/* Scales */
static double Sp;
static double Su;
static double Sw;
static double Smu;
static double St;
static double Ssig;
static double Ssigb;
static double eps = 0;

#define LEN_SCALING 1
#define PRES_SCALING 1
#define COORD_SCALING				\
    x *= LEN_SCALING / Sx;			\
    y *= LEN_SCALING / Sx;			\
    z *= LEN_SCALING / Sz;			


/* Input: [m], [degree] */
void 
func_init_params(double Lx0, double alpha0)
{
    Lx = Lx0;			// [m]
    alpha = alpha0;		// [degree]

    /* Basic parameters */
    n = 3.		; // Glen’s parameter
    rho = 910.		; // [kg/mˆ3]
    g = 9.81		; // [m/secˆ2]
    A = 1.e-16		; // [Paˆ(-n)aˆ(-1)]
    spyr = 31556926.	; // [sec/a]
    Sx = Lx		; // [m]
    Sz = 1000.		; // [m]
    D = Sz/Sx	        ; // aspect ratio

    /* Scales */
    Sp    = rho*g*Sz		;	// [Pa=kg/m/secˆ2]
    Su    = pow(2*Sp, n)*Sx*A	;	// [m/a]
    Sw    = Su*Sz/Sx		;	// [m/a]
    Smu   = 0.5*pow(A, (-1./n)) *
	pow(Su/Sx, (1.-n)/n)	;	// [Pa secˆ2]
    St    = Sx/Su		;	// [a]
    Ssig  = Sp/Sz		;	// stress scale [J=Pa/m]
    Ssigb = Sp			;	// bound.stress scale [Pa]

    printf("* Delta %e\n", D);
    return;
}



void
set_func_time(double tt)
{
    t = tt / St;
}


/*
 * -----------
 * functions:
 * -----------
 * 
 * u v w
 * ux uy uz
 * vx vy vz
 * wx wy wz
 * uxx uxy uxz uyx uyy uyz uzx uzy uzz
 * vxx vxy vxz vyx vyy vyz vzx vzy vzz
 * wxx wxy wxz wyx wyy wyz wzx wzy wzz
 *
 * mu dmux dmuy dmuz
 * p px py pz
 * b bx by bz
 * s sx sy sz
 * */

    
double
pow_(double a, double b)
{
   if (fabs(a) < 1e-30)
      return 0;
   else
      return pow(a, b);
}
#define pow(a, b) pow_(a, b)
// u
static  double func_u_(double x, double y, double z){
   return  cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1);
}


// v
static  double func_v_(double x, double y, double z){
   return  cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1;
}


// w
static  double func_w_(double x, double y, double z){
   return  (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)));
}


// ux
static  double func_ux_(double x, double y, double z){
   return  cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y));
}


// uy
static  double func_uy_(double x, double y, double z){
   return  cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1);
}


// uz
static  double func_uz_(double x, double y, double z){
   return  0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1);
}


// uxx
static  double func_uxx_(double x, double y, double z){
   return  cx * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y));
}


// uxy
static  double func_uxy_(double x, double y, double z){
   return  cx * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y));
}


// uxz
static  double func_uxz_(double x, double y, double z){
   return  cx * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)));
}


// uyx
static  double func_uyx_(double x, double y, double z){
   return  cx * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y));
}


// uyy
static  double func_uyy_(double x, double y, double z){
   return  cx * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * pow(0.1e1 - exp(-ct * t), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y));
}


// uyz
static  double func_uyz_(double x, double y, double z){
   return  cx * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1));
}


// uzx
static  double func_uzx_(double x, double y, double z){
   return  0.12e2 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) - 0.16e2 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y));
}


// uzy
static  double func_uzy_(double x, double y, double z){
   return  0.12e2 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.16e2 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1);
}


// uzz
static  double func_uzz_(double x, double y, double z){
   return  -0.12e2 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1);
}


// vx
static  double func_vx_(double x, double y, double z){
   return  -cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t);
}


// vy
static  double func_vy_(double x, double y, double z){
   return  -cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t);
}


// vz
static  double func_vz_(double x, double y, double z){
   return  0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t);
}


// vxx
static  double func_vxx_(double x, double y, double z){
   return  0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) - 0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) + 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t);
}


// vxy
static  double func_vxy_(double x, double y, double z){
   return  0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) - 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t);
}


// vxz
static  double func_vxz_(double x, double y, double z){
   return  -0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.4e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t);
}


// vyx
static  double func_vyx_(double x, double y, double z){
   return  0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) - 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t);
}


// vyy
static  double func_vyy_(double x, double y, double z){
   return  0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) - 0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * pow(0.1e1 - exp(-ct * t), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * pow(0.1e1 - exp(-ct * t), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) + 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t);
}


// vyz
static  double func_vyz_(double x, double y, double z){
   return  -0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) + 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.4e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t);
}


// vzx
static  double func_vzx_(double x, double y, double z){
   return  -0.20e2 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.12e2 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.10e2 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.6e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t);
}


// vzy
static  double func_vzy_(double x, double y, double z){
   return  -0.20e2 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.12e2 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.10e2 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.6e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * exp(-ct * t) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t);
}


// vzz
static  double func_vzz_(double x, double y, double z){
   return  -0.12e2 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) + 0.6e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t);
}


// wx
static  double func_wx_(double x, double y, double z){
   return  (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))));
}


// wy
static  double func_wy_(double x, double y, double z){
   return  (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)));
}


// wz
static  double func_wz_(double x, double y, double z){
   return  0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1));
}


// wxx
static  double func_wxx_(double x, double y, double z){
   return  (cx * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + 0.2e1 * (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) - 0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) - 0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) + 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + 0.2e1 * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))));
}


// wxy
static  double func_wxy_(double x, double y, double z){
   return  (cx * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - 0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)))) + (0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) - 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))));
}


// wxz
static  double func_wxz_(double x, double y, double z){
   return  cx * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + 0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + (-0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.4e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)));
}


// wyx
static  double func_wyx_(double x, double y, double z){
   return  (cx * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - 0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)))) + (0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) - 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))));
}


// wyy
static  double func_wyy_(double x, double y, double z){
   return  (cx * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * pow(0.1e1 - exp(-ct * t), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + 0.2e1 * (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + 0.4e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) - 0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * pow(0.1e1 - exp(-ct * t), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * pow(0.1e1 - exp(-ct * t), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) + 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + 0.2e1 * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.6e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * pow(0.31415926535897932385e1, 0.3e1) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * pow(0.31415926535897932385e1, 0.3e1) * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) - 0.4e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))));
}


// wyz
static  double func_wyz_(double x, double y, double z){
   return  cx * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + 0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) + (-0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) + 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.4e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1));
}


// wzx
static  double func_wzx_(double x, double y, double z){
   return  0.12e2 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) - 0.16e2 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + (-0.20e2 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.12e2 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.10e2 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.6e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)));
}


// wzy
static  double func_wzy_(double x, double y, double z){
   return  0.12e2 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.16e2 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) + (-0.20e2 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.12e2 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.10e2 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.6e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * exp(-ct * t) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1));
}


// wzz
static  double func_wzz_(double x, double y, double z){
   return  -0.12e2 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + 0.8e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-0.12e2 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) + 0.6e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + 0.2e1 * (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1));
}


// mu
static  double func_mu_(double x, double y, double z){
   return  pow(pow(cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t), 0.2e1) / 0.4e1 + pow(0.4e1 / delta * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))))), 0.2e1) / 0.4e1 + pow(0.1e1 / delta * (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)))), 0.2e1) / 0.4e1 - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) - (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))), -0.1e1 / 0.3e1);
}


// p
static  double func_p_(double x, double y, double z){
   return  0.2e1 * pow(pow(cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t), 0.2e1) / 0.4e1 + pow(0.4e1 / delta * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))))), 0.2e1) / 0.4e1 + pow(0.1e1 / delta * (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)))), 0.2e1) / 0.4e1 - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) - (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))), -0.1e1 / 0.3e1) * (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * pow(pow(cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t), 0.2e1) / 0.4e1 + pow(0.4e1 / delta * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))))), 0.2e1) / 0.4e1 + pow(0.1e1 / delta * (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)))), 0.2e1) / 0.4e1 - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) - (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))), -0.1e1 / 0.3e1) * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) + x * tan(alpha) / delta - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + z;
}


// px
static  double func_px_(double x, double y, double z){
   return  0.2e1 * pow(pow(cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t), 0.2e1) / 0.4e1 + pow(0.4e1 / delta * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))))), 0.2e1) / 0.4e1 + pow(0.1e1 / delta * (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)))), 0.2e1) / 0.4e1 - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) - (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))), -0.1e1 / 0.3e1) * (cx * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * pow(pow(cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t), 0.2e1) / 0.4e1 + pow(0.4e1 / delta * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))))), 0.2e1) / 0.4e1 + pow(0.1e1 / delta * (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)))), 0.2e1) / 0.4e1 - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) - (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))), -0.1e1 / 0.3e1) * (0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) - 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) + tan(alpha) / delta - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t));
}


// py
static  double func_py_(double x, double y, double z){
   return  0.2e1 * pow(pow(cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t), 0.2e1) / 0.4e1 + pow(0.4e1 / delta * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))))), 0.2e1) / 0.4e1 + pow(0.1e1 / delta * (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)))), 0.2e1) / 0.4e1 - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) - (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))), -0.1e1 / 0.3e1) * (cx * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * pow(pow(cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t), 0.2e1) / 0.4e1 + pow(0.4e1 / delta * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))))), 0.2e1) / 0.4e1 + pow(0.1e1 / delta * (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)))), 0.2e1) / 0.4e1 - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) - (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))), -0.1e1 / 0.3e1) * (0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) - 0.2e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * pow(0.1e1 - exp(-ct * t), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.3e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * pow(0.1e1 - exp(-ct * t), 0.2e1) + 0.32e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.8e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - 0.20e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1, 0.2e1) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) + 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t) + 0.2e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t));
}


// pz
static  double func_pz_(double x, double y, double z){
   return  0.2e1 * pow(pow(cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t), 0.2e1) / 0.4e1 + pow(0.4e1 / delta * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))))), 0.2e1) / 0.4e1 + pow(0.1e1 / delta * (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)))), 0.2e1) / 0.4e1 - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) - (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))), -0.1e1 / 0.3e1) * cx * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) + 0.2e1 * pow(pow(cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t), 0.2e1) / 0.4e1 + pow(0.4e1 / delta * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))))), 0.2e1) / 0.4e1 + pow(0.1e1 / delta * (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) + delta * ((cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + 0.2e1 * cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * cos(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1))) + (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x), 0.2e1) * pow(cos(0.2e1 * 0.31415926535897932385e1 * y), 0.2e1) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.2e1 * sin(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)))), 0.2e1) / 0.4e1 - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) - (cx * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) - cbx * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) - cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y))) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) - (-cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) - cby * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) / 0.2e1 - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (-0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) + 0.4e1 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) * (0.4e1 * cx * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * ((-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cx * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cbx / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) * (-(-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + (-tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t))) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1)) + (0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) - 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t)) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) * (0.1e1 - (-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))) + (cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) + cby / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.1e1 - pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.4e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1) * (-sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) + sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1))), -0.1e1 / 0.3e1) * (-0.4e1 * cy * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) + cy / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) + 0.2e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.6e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1) - 0.1e1 / (sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1) * (0.12e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.2e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.4e1) * sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - 0.16e2 * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * (sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t)) - sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1)) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1 + 0.4e1 * pow(sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 + 0.1e1 - sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1, -0.5e1) * pow(-x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1 - z, 0.3e1) * cx * cos(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * exp(-ct * t)) + 0.1e1;
}


// b
static  double func_b_(double x, double y, double z){
   return  -x * tan(alpha) / delta - 0.1e1 + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) / 0.2e1;
}


// bx
static  double func_bx_(double x, double y, double z){
   return  -tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y);
}


// by
static  double func_by_(double x, double y, double z){
   return  sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1;
}


// bz
static  double func_bz_(double x, double y, double z){
   return  0;
}


// s
static  double func_s_(double x, double y, double z){
   return  -x * tan(alpha) / delta + sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t)) / 0.2e1;
}


// sx
static  double func_sx_(double x, double y, double z){
   return  -tan(alpha) / delta + cos(0.2e1 * 0.31415926535897932385e1 * x) * 0.31415926535897932385e1 * sin(0.2e1 * 0.31415926535897932385e1 * y) * (0.1e1 - exp(-ct * t));
}


// sy
static  double func_sy_(double x, double y, double z){
   return  sin(0.2e1 * 0.31415926535897932385e1 * x) * cos(0.2e1 * 0.31415926535897932385e1 * y) * 0.31415926535897932385e1 * (0.1e1 - exp(-ct * t));
}


// sz
static  double func_sz_(double x, double y, double z){
   return  0;
}


// a
static  double func_a_(double x, double y, double z){
       return  ct * sin(0.2e1 * 0.31415926535897932385e1 * x) * sin(0.2e1 * 0.31415926535897932385e1 * y) * exp(-ct * t) / 0.2e1;
}
#undef pow



#define DIFF_DIFF_U 				\
	double sxx = 2 * mu * ux - p;		\
	double sxy = mu * (uy + vx);		\
	double sxz = mu * (uz/D + wx*D);	\
	double syx = mu * (vx + uy);		\
	double syy = 2 * mu * vy - p;		\
	double syz = mu * (vz/D + wy*D);	\
	double szx = mu * (wx*D + uz/D);	\
	double szy = mu * (wy*D + vz/D);	\
	double szz = 2 * mu * wz - p;		

void func_u(double x, double y, double z, double *u) 
/* Input : [m]
 * Output: [m/a] */
{
    COORD_SCALING;

    u[0] = func_u_(x, y, z) * Su; 
    u[1] = func_v_(x, y, z) * Su; 
    u[2] = func_w_(x, y, z) * Sw; 

}

void func_p(double x, double y, double z, double *p) 
/* Input : [m]
 * Output: [Pa]/PresS */
{
    COORD_SCALING;

    p[0] = func_p_(x, y, z) * Sp;
    p[0] /= PRES_SCALING;
}

void func_gradu(double x, double y, double z, double *gradu)
/* Unused */
{
    COORD_SCALING;

    gradu[0] = func_ux_(x, y, z) * Su*LEN_SCALING/Sx ;
    gradu[1] = func_uy_(x, y, z) * Su*LEN_SCALING/Sx ;
    gradu[2] = func_uz_(x, y, z) * Su*LEN_SCALING/Sz ;

    gradu[3] = func_vx_(x, y, z) * Su*LEN_SCALING/Sx ;
    gradu[4] = func_vy_(x, y, z) * Su*LEN_SCALING/Sx ;
    gradu[5] = func_vz_(x, y, z) * Su*LEN_SCALING/Sz ;

    gradu[6] = func_wx_(x, y, z) * Sw*LEN_SCALING/Sx ;
    gradu[7] = func_wy_(x, y, z) * Sw*LEN_SCALING/Sx ;
    gradu[8] = func_wz_(x, y, z) * Sw*LEN_SCALING/Sz ;
}



void func_F(double x, double y, double z, double *f) 
/* Compensation terms, 
 * Input : [m]
 * Output: [Pa/m] */
{
    COORD_SCALING;

    double ux = func_ux_(x, y, z);
    double uy = func_uy_(x, y, z);
    double uz = func_uz_(x, y, z);
    double uxx = func_uxx_(x, y, z);
    double uxy = func_uxy_(x, y, z);
    double uxz = func_uxz_(x, y, z);
    double uyx = uxy;
    double uyy = func_uyy_(x, y, z);
    double uyz = func_uyz_(x, y, z);
    double uzx = uxz;
    double uzy = uyz;
    double uzz = func_uzz_(x, y, z);

    double vx = func_vx_(x, y, z);
    double vy = func_vy_(x, y, z);
    double vz = func_vz_(x, y, z);
    double vxx = func_vxx_(x, y, z);
    double vxy = func_vxy_(x, y, z);
    double vxz = func_vxz_(x, y, z);
    double vyx = vxy;
    double vyy = func_vyy_(x, y, z);
    double vyz = func_vyz_(x, y, z);
    double vzx = vxz;
    double vzy = vyz;
    double vzz = func_vzz_(x, y, z);

    double wx = func_wx_(x, y, z);
    double wy = func_wy_(x, y, z);
    double wz = func_wz_(x, y, z);
    double wxx = func_wxx_(x, y, z);
    double wxy = func_wxy_(x, y, z);
    double wxz = func_wxz_(x, y, z);
    double wyx = wxy;
    double wyy = func_wyy_(x, y, z);
    double wyz = func_wyz_(x, y, z);
    double wzx = wxz;
    double wzy = wyz;
    double wzz = func_wzz_(x, y, z);
    double mu = func_mu_(x, y, z);


    double dmux, dmuy, dmuz;

    //
    // Note: set eps mu 1e12
    //
    if (2*Smu*mu > 1e12) {
	mu = 1e12/Smu/2;
	dmux = 0;
	dmuy = 0;
	dmuz = 0;
    } else {
	dmux = -pow(pow(uy + vx, 0.2e1) / 0.4e1 + pow(0.1e1 / delta * uz + delta * wx, 0.2e1) / 0.4e1 + pow(0.1e1 / delta * vz + delta * wy, 0.2e1) / 0.4e1 - ux * vy - ux * wz - vy * wz, -0.4e1 / 0.3e1) * ((uy + vx) * (uxy + vxx) / 0.2e1 + (0.1e1 / delta * uz + delta * wx) * (0.1e1 / delta * uxz + delta * wxx) / 0.2e1 + (0.1e1 / delta * vz + delta * wy) * (0.1e1 / delta * vxz + delta * wxy) / 0.2e1 - uxx * vy - ux * vxy - uxx * wz - ux * wxz - vxy * wz - vy * wxz) / 0.3e1;
	dmuy = -pow(pow(uy + vx, 0.2e1) / 0.4e1 + pow(0.1e1 / delta * uz + delta * wx, 0.2e1) / 0.4e1 + pow(0.1e1 / delta * vz + delta * wy, 0.2e1) / 0.4e1 - ux * vy - ux * wz - vy * wz, -0.4e1 / 0.3e1) * ((uy + vx) * (uyy + vxy) / 0.2e1 + (0.1e1 / delta * uz + delta * wx) * (0.1e1 / delta * uyz + delta * wxy) / 0.2e1 + (0.1e1 / delta * vz + delta * wy) * (0.1e1 / delta * vyz + delta * wyy) / 0.2e1 - uxy * vy - ux * vyy - uxy * wz - ux * wyz - vyy * wz - vy * wyz) / 0.3e1;
	dmuz = -pow(pow(uy + vx, 0.2e1) / 0.4e1 + pow(0.1e1 / delta * uz + delta * wx, 0.2e1) / 0.4e1 + pow(0.1e1 / delta * vz + delta * wy, 0.2e1) / 0.4e1 - ux * vy - ux * wz - vy * wz, -0.4e1 / 0.3e1) * ((uy + vx) * (uyz + vxz) / 0.2e1 + (0.1e1 / delta * uz + delta * wx) * (0.1e1 / delta * uzz + delta * wxz) / 0.2e1 + (0.1e1 / delta * vz + delta * wy) * (0.1e1 / delta * vzz + delta * wyz) / 0.2e1 - uxz * vy - ux * vyz - uxz * wz - ux * wzz - vyz * wz - vy * wzz) / 0.3e1;
    }
    

    double px = func_px_(x, y, z);
    double py = func_py_(x, y, z);
    double pz = func_pz_(x, y, z);

    /* 
     * pressure
     *    p = 2*mu*(diff(u, x) + diff(v, y))- (s-z)
     *    px += 2*dmux*(ux + vy)
     *    py += 2*dmuy*(ux + vy)
     *    pz += 2*dmuz*(ux + vy)
     * */

    px += 2*dmux * (ux + vy);
    py += 2*dmuy * (ux + vy);
    pz += 2*dmuz * (ux + vy);
     

    /* ALL terms */
    double rx =
    	mu * (2*uxx) + dmux * (2*ux) - px
    	+ mu * (uyy + vxy) + dmuy * (uy + vx)
    	+ mu/D * (uzz/D + wxz*D) + dmuz/D * (uz/D + wx*D);

    double ry = 
	mu * (vxx + uyx) + dmux * (vx + uy)
	+ mu * (2*vyy) + dmuy * (2*vy) - py
	+ mu/D * (vzz/D + wyz*D) + dmuz/D * (vz/D + wy*D);

    double rz = 
	mu * (uzx/D + wxx*D) + dmux * (uz/D + wx*D)
	+ mu * (vzy/D + wyy*D) + dmuy * (vz/D + wy*D)
	+ mu/D * (2*wzz) + dmuz/D * (2*wz) - pz/D;

    rx *= D;
    ry *= D;
    rz *= D;

    f[0] = rx * Ssig;
    f[1] = ry * Ssig;
    f[2] = (rz - 1) * Ssig;

}















void func_f(double x, double y, double z, double *f) 
/* Upper surface: 
 * Input : [m]
 * Output: [Pa] */
{
    COORD_SCALING;

    double mu = func_mu_(x, y, z);
    double ux = func_ux_(x, y, z);
    double uy = func_uy_(x, y, z);
    double uz = func_uz_(x, y, z);
    double vx = func_vx_(x, y, z);
    double vy = func_vy_(x, y, z);
    double vz = func_vz_(x, y, z);
    double wx = func_wx_(x, y, z);
    double wy = func_wy_(x, y, z);
    double wz = func_wz_(x, y, z);
    double p = func_p_(x, y, z);
    //double s = func_s_(x, y, z);
    double sx = func_sx_(x, y, z);
    double sy = func_sy_(x, y, z);
    //double sz = func_sz_(x, y, z);

    //
    // Note: set eps mu 1e12
    //
    if (2*Smu*mu > 1e12) {
	mu = 1e12/Smu/2;
    }

    /* Unit: Pa */
    DIFF_DIFF_U;

    double rs = sqrt(1 + SQU(D*sx) + SQU(D*sy));
    double rsx = 1/rs * (-D*sx * sxx - D*sy * sxy + sxz);
    double rsy = 1/rs * (-D*sx * syx - D*sy * syy + syz);
    double rsz = 1/rs * (-D*sx * szx - D*sy * szy + szz);

    f[0] = rsx * Ssigb;
    f[1] = rsy * Ssigb;
    f[2] = rsz * Ssigb;
}








void func_s(double x, double y, double z, double *s)
/* Input : [m]
 * Output: [m] */
{
    x /= Sx;
    y /= Sx;
    z = 0.;
    s[0] = func_s_(x, y, 0) * Sz;
}

void func_b(double x, double y, double z, double *b)
/* Input : [m]
 * Output: [m] */
{
    x /= Sx;
    y /= Sx;
    z = 0.;
    b[0] = func_b_(x, y, 0) * Sz;
}



void func_mu(double x, double y, double z, double *value)
/* Input : [m]
 * Output: [Pa secˆ2]  */
{
    COORD_SCALING;
    double mu = func_mu_(x, y, z);

    mu *= Smu;
    value[0] = 2*mu;		
}



void func_a(double x, double y, double *value)
/* Input : [m]
 * Output: [m/a]
 */
{
    x *= LEN_SCALING / Sx;
    y *= LEN_SCALING / Sx;

    *value = Sw * func_a_(x, y, t);
}

#undef delta
